# -*- coding: utf-8 -*-
# (c) 2008 Canonical Ltd.
# Author: Martin Pitt <martin.pitt@ubuntu.com>
# License: GPL v2 or later

from jockey.xorg_driver import XorgDriverHandler

# dummy stub for xgettext
def _(x): return x

class FglrxDriver(XorgDriverHandler):
    def __init__(self, backend):
        self._free = False
        XorgDriverHandler.__init__(self, backend, 'fglrx', 'xorg-driver-fglrx',
            'fglrx', 'ati', add_modules=['glx'],
            name=_('ATI accelerated graphics driver'),
            description=_('3D-accelerated proprietary graphics driver for '
                'ATI cards.'),
            rationale=_('This driver is required to fully utilise '
                'the 3D potential of ATI graphics cards, as well as provide '
                '2D acceleration of newer cards.'))

    def enable_config_hook(self):
        # X.org does not work otherwise
        if len(self.xorg_conf.getSections('Screen')) == 0:
            s = self.xorg_conf.makeSection(None, ['Section', 'Screen'])
            s.identifier = 'Default Screen'
            self.xorg_conf.append(s)
	self.xorg_conf.getSections('Screen')[0].defaultdepth = 24

    def enables_composite(self):
        '''Return whether this driver supports the composite extension.'''

        # the radeon X.org driver supports composite nowadays, so don't force
        # installation of fglrx upon those users. Treat absent driver
        # configuration as radeon, since that's what X.org should autodetect.
        # Only suggest fglrx if people use something else, like vesa.
        devices = self.xorg_conf.getSections('device')
        if len(devices) == 0 or devices[0].driver in ['fglrx', 'ati', 'radeon', None]:
            return False

        return True

